==> nextcloud-29.0.5.tgz: nextcloud/apps/federatedfilesharing/l10n/cs.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Neplatný identifikátor v rámci federovaného cloudu",
    "Server to server sharing is not enabled on this server" : "Sdílení ze serveru na server není na tomto serveru povoleno",
    "Couldn't establish a federated share." : "Nepodařilo se ustavit federované sdílení.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Nepodařilo se ustavit federované sdílení – možná je nesprávné heslo.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Požadavek na federované sdílení byl odeslán, obdržíte pozvánku. Podívejte se do upozornění pro vás.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Nepodařilo se ustavit federované sdílení – vypadá to, že server, se kterým má být federováno, je příliš starý (Nextcloud verze 9 a starší).",
    "It is not allowed to send federated group shares from this server." : "Z tohoto serveru není povoleno posílat federovaná skupinová sdílení.",
    "Federated shares require read permissions" : "Propojené sdílení vyžaduje oprávnění ke čtení",
    "File is already shared with %s" : "Soubor už je sdílen s %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Sdílení %1$s se nezdařilo, %2$s se nepodařilo nalézt, server pravděpodobně právě není dostupný nebo používá self-signed certifikát.",
    "Could not find share" : "Nedaří se nalézt sdílení",
    "Federated sharing" : "Federované sdílení",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Obdrželi jste {share} jako vzdálené sdílení od {user} (jménem {behalf})",
    "You received {share} as a remote share from {user}" : "Obdrželi jste {share} jako vzdálené sdílení od {user}",
    "Accept" : "Přijmout",
    "Decline" : "Zamítnout",
    "Federated Cloud Sharing" : "Sdílení v rámci federovaného cloudu",
    "Sharing" : "Sdílení",
    "Federated file sharing" : "Federované sdílení souborů",
    "Provide federated file sharing across servers" : "Poskytnout federované sdílení souborů napříč servery",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Upravte, jak mohou uživatelé sdílet mezi servery. Týká se sdílení mezi uživateli na tomto serveru a stejně také uživatelů federovaného sdílení.",
    "Unable to update federated files sharing config" : "Nedaří se aktualizovat nastavení federovaného sdílení souborů",
    "Federated Cloud" : "Federovaný cloud",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Můžete sdílet s kýmkoliv, kdo používá Nextcloud nebo jiný server či služby, kompatibilní se standardem Open Cloud Mesh (OCM)! Stačí do dialogu pro sdílení zadat jejich jejich identif. v rámci sdruženého cloudu. Má podobu person@cloud.example.com",
    "Your Federated Cloud ID:" : "Váš identifikátor v rámci federovaného cloudu:",
    "Share it so your friends can share files with you:" : "Podělte se o to, aby mohli vaši přátelé s vámi mohli sdílet soubory:",
    "Facebook" : "Facebook",
    "Twitter" : "Twitter",
    "Diaspora" : "Diaspora",
    "Add to your website" : "Přidat na svou webovou stránku",
    "Share with me via Nextcloud" : "Sdílet se mnou přes Nextcloud",
    "HTML Code:" : "HTML kód:",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Sdílejte se mnou prostřednictvím mého #Nextcloud identifikátoru v rámci federovaného cloudu – více na {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Sdílejte se mnou pomocí mého #Nextcloud identifikátoru v rámci federovaného cloudu",
    "Cloud ID copied to the clipboard" : "Cloudový identifikátor zkopírován do schránky",
    "Copy to clipboard" : "Zkopírovat do schránky",
    "Clipboard is not available" : "Schránka není k dispozici",
    "Copied!" : "Zkopírováno",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Chcete přidat vzdálené sdílení {name} od {owner}@{remote}?",
    "Remote share" : "Vzdálené sdílení",
    "Remote share password" : "Heslo ke vzdálenému sdílení",
    "Cancel" : "Storno",
    "Add remote share" : "Přidat vzdálené sdílení",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Sdílení položky %1$s se nezdařilo, protože ta je už s uživatelem %2$s sdílena",
    "Not allowed to create a federated share with the same user" : "Není možné vytvářet federované sdílení mezi jedním a tím samým uživatelem",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Upravte to, jak lidé mohou sdílet mezi servery. Součástí toho jsou také i sdílení mezi uživateli na tomto serveru, pokud používají federované sdílení.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Umožnit uživatelům na tomto serveru posílat sdílení na ostatní servery (tato volba také umožňuje WebDAV přístup k veřejným sdílením)",
    "Allow users on this server to receive shares from other servers" : "Povolit uživatelům na tomto serveru přijímat sdílení z jiných serverů",
    "Allow users on this server to send shares to groups on other servers" : "Povolit uživatelům na tomto serveru zasílat sdílení skupinám na ostatních serverech",
    "Allow users on this server to receive group shares from other servers" : "Povolit uživatelům na tomto serveru přijímat skupinová sdílení z jiných serverů",
    "Search global and public address book for users" : "Hledat uživatele v globálním a veřejném adresáři kontaktů",
    "Allow users to publish their data to a global and public address book" : "Povolit uživatelům publikování jejich dat do globálního a sdíleného adresáře kontaktů"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-29.0.10.tgz: nextcloud/apps/federatedfilesharing/l10n/cs.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Neplatný identifikátor v rámci federovaného cloudu",
    "Server to server sharing is not enabled on this server" : "Sdílení ze serveru na server není na tomto serveru povoleno",
    "Couldn't establish a federated share." : "Nepodařilo se ustavit federované sdílení.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Nepodařilo se ustavit federované sdílení – možná je nesprávné heslo.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Požadavek na federované sdílení byl odeslán, obdržíte pozvánku. Podívejte se do upozornění pro vás.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Nepodařilo se ustavit federované sdílení – vypadá to, že server, se kterým má být federováno, je příliš starý (Nextcloud verze 9 a starší).",
    "It is not allowed to send federated group shares from this server." : "Z tohoto serveru není povoleno posílat federovaná skupinová sdílení.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Sdílení položky %1$s se nezdařilo, protože ta je už s účtem %2$s sdílena",
    "Not allowed to create a federated share to the same account" : "Není možné vytvářet federované sdílení mezi jedním a tím samým účtem",
    "Federated shares require read permissions" : "Propojené sdílení vyžaduje oprávnění ke čtení",
    "File is already shared with %s" : "Soubor už je sdílen s %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Sdílení %1$s se nezdařilo, %2$s se nepodařilo nalézt, server pravděpodobně právě není dostupný nebo používá self-signed certifikát.",
    "Could not find share" : "Nedaří se nalézt sdílení",
    "Federated sharing" : "Federované sdílení",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Obdrželi jste {share} jako vzdálené sdílení od {user} (jménem {behalf})",
    "You received {share} as a remote share from {user}" : "Obdrželi jste {share} jako vzdálené sdílení od {user}",
    "Accept" : "Přijmout",
    "Decline" : "Zamítnout",
    "Federated Cloud Sharing" : "Sdílení v rámci federovaného cloudu",
    "Sharing" : "Sdílení",
    "Federated file sharing" : "Federované sdílení souborů",
    "Provide federated file sharing across servers" : "Poskytnout federované sdílení souborů napříč servery",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Upravte, jak mohou lidé sdílet mezi servery. Týká se sdílení mezi lidmi na tomto serveru a stejně tak uživatelů federovaného sdílení.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Umožnit lidem na tomto serveru posílat sdílení na ostatní servery (tato volba také umožňuje WebDAV přístup k veřejným sdílením)",
    "Allow people on this server to receive shares from other servers" : "Povolit lidem na tomto serveru přijímat sdílení z jiných serverů",
    "Allow people on this server to send shares to groups on other servers" : "Povolit lidem na tomto serveru zasílat sdílení skupinám na ostatních serverech",
    "Allow people on this server to receive group shares from other servers" : "Povolit lidem na tomto serveru přijímat skupinová sdílení z jiných serverů",
    "Search global and public address book for people" : "Vyhledávat lidi v globálním a veřejném adresáři kontaktů",
    "Allow people to publish their data to a global and public address book" : "Povolit lidem publikování jejich dat do globálního a sdíleného adresáře kontaktů",
    "Unable to update federated files sharing config" : "Nedaří se aktualizovat nastavení federovaného sdílení souborů",
    "Federated Cloud" : "Federovaný cloud",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Můžete sdílet s kýmkoliv, kdo používá Nextcloud nebo jiný server či služby, kompatibilní se standardem Open Cloud Mesh (OCM)! Stačí do dialogu pro sdílení zadat jejich jejich identif. v rámci sdruženého cloudu. Má podobu person@cloud.example.com",
    "Your Federated Cloud ID" : "Váš identifikátor v rámci fedorovaného cloudu",
    "Share it so your friends can share files with you:" : "Podělte se o to, aby mohli vaši přátelé s vámi mohli sdílet soubory:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (dříve Twitter)",
    "formerly Twitter" : "dříve Twitter",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Přidat na svou webovou stránku",
    "Share with me via Nextcloud" : "Sdílet se mnou přes Nextcloud",
    "HTML Code:" : "HTML kód:",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Sdílejte se mnou prostřednictvím mého #Nextcloud identifikátoru v rámci federovaného cloudu – více na {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Sdílejte se mnou pomocí mého #Nextcloud identifikátoru v rámci federovaného cloudu",
    "Cloud ID copied to the clipboard" : "Cloudový identifikátor zkopírován do schránky",
    "Copy to clipboard" : "Zkopírovat do schránky",
    "Clipboard not available. Please copy the cloud ID manually." : "Schránka není k dispozici. Zkopírujte cloudový identifikátor ručně.",
    "Copied!" : "Zkopírováno",
    "Cancel" : "Storno",
    "Add remote share" : "Přidat vzdálené sdílení",
    "Remote share" : "Vzdálené sdílení",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Chcete přidat vzdálené sdílení {name} od {owner}@{remote}?",
    "Remote share password" : "Heslo ke vzdálenému sdílení",
    "Incoming share could not be processed" : "Příchozí sdílení se nepodařilo zpracovat",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Sdílení položky %1$s se nezdařilo, protože ta je už s uživatelem %2$s sdílena",
    "Not allowed to create a federated share with the same user" : "Není možné vytvářet federované sdílení mezi jedním a tím samým uživatelem",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Upravte to, jak lidé mohou sdílet mezi servery. Součástí toho jsou také i sdílení mezi uživateli na tomto serveru, pokud používají federované sdílení.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Umožnit uživatelům na tomto serveru posílat sdílení na ostatní servery (tato volba také umožňuje WebDAV přístup k veřejným sdílením)",
    "Allow users on this server to receive shares from other servers" : "Povolit uživatelům na tomto serveru přijímat sdílení z jiných serverů",
    "Allow users on this server to send shares to groups on other servers" : "Povolit uživatelům na tomto serveru zasílat sdílení skupinám na ostatních serverech",
    "Allow users on this server to receive group shares from other servers" : "Povolit uživatelům na tomto serveru přijímat skupinová sdílení z jiných serverů",
    "Search global and public address book for users" : "Hledat uživatele v globálním a veřejném adresáři kontaktů",
    "Allow users to publish their data to a global and public address book" : "Povolit uživatelům publikování jejich dat do globálního a sdíleného adresáře kontaktů",
    "Your Federated Cloud ID:" : "Váš identifikátor v rámci federovaného cloudu:",
    "Twitter" : "Twitter",
    "Diaspora" : "Diaspora",
    "Clipboard is not available" : "Schránka není k dispozici"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
